import React, { useState } from "react";
import PropTypes from "prop-types";
import clsx from "clsx";
import { makeStyles, useTheme } from "@mui/material/styles";
import { Drawer, List, Divider, IconButton, ListItemIcon, ListItemText } from "@mui/material";
import ChevronLeftIcon from "@mui/icons-material/ChevronLeft";
import ChevronRightIcon from "@mui/icons-material/ChevronRight";
import ListItem from "@mui/material/ListItem";
import BuildIcon from "@mui/icons-material/Build";
import DnsIcon from "@mui/icons-material/Dns";
import DeviceHubIcon from "@mui/icons-material/DeviceHub";
import SettingsIcon from "@mui/icons-material/Settings";
import DashboardIcon from "@mui/icons-material/Dashboard";
import FeaturedPlayListIcon from "@mui/icons-material/FeaturedPlayList";
import { useNavigate } from "react-router-dom";
import { useTranslation } from "react-i18next";
import styles from "./styles";

const useStyles = makeStyles(styles);

const menu = [
  {
    order: 0,
    items: [
      {
        code: "dashboard",
        name: "Menu.Dashboard",
        route: "/dashboard",
        icon: <DashboardIcon />,
        order: 0
      },
      {
        code: "machines",
        name: "Menu.Machines",
        route: "/machines",
        icon: <DnsIcon />,
        order: 1
      },
      {
        code: "system",
        name: "Menu.System",
        route: "/system",
        icon: <DeviceHubIcon />,
        order: 2
      }
    ]
  },
  {
    order: 1,
    items: [
      {
        code: "administration",
        name: "Menu.Administration",
        route: "/administration",
        icon: <BuildIcon />,
        order: 0
      },
      {
        code: "settings",
        name: "Menu.Settings",
        route: "/settings",
        icon: <SettingsIcon />,
        order: 1
      }
    ]
  },
  {
    order: 2,
    items: [
      {
        code: "about",
        name: "Menu.About",
        route: "/about",
        icon: <FeaturedPlayListIcon />,
        order: 0
      }
    ]
  }
];

const sortedMenu = menu.sort((i1, i2) => i1 - i2);

const Sidebar = ({ open, handleDrawerClose }) => {
  const [selected, setSelected] = useState(null);

  const classes = useStyles();
  const theme = useTheme();
  const navigate = useNavigate();
  const { t } = useTranslation();

  const handleClick = route => () => {
    setSelected(route);
    navigate(route);
  };

  const isSelected = key => selected === key;

  return (
    <Drawer
      variant="permanent"
      className={clsx(classes.drawer, {
        [classes.drawerOpen]: open,
        [classes.drawerClose]: !open
      })}
      classes={{
        paper: clsx({
          [classes.drawerOpen]: open,
          [classes.drawerClose]: !open
        })
      }}
    >
      <div className={classes.toolbar}>
        <IconButton onClick={handleDrawerClose}>
          {theme.direction === "rtl" ? <ChevronRightIcon /> : <ChevronLeftIcon />}
        </IconButton>
      </div>
      <Divider />

      {sortedMenu.map((menu, index) => {
        const isLast = index === sortedMenu.length - 1;
        return (
          <React.Fragment key={`menu-${menu.order}`}>
            <List>
              {menu.items
                .sort((i1, i2) => i1 - i2)
                .map(item => (
                  <ListItem button key={item.code} onClick={handleClick(item.route)} selected={isSelected(item.route)}>
                    <ListItemIcon>{item.icon}</ListItemIcon>
                    <ListItemText primary={t(item.name)} />
                  </ListItem>
                ))}
            </List>
            {!isLast && <Divider />}
          </React.Fragment>
        );
      })}
    </Drawer>
  );
};

Sidebar.propTypes = {
  open: PropTypes.bool.isRequired,
  handleDrawerClose: PropTypes.func.isRequired
};

export default Sidebar;
